==> index_now-3.1.0.tar.gz: index_now/tests/src/Unit/TermOperationsTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\index_now\TermOperations;
use Drupal\taxonomy\Entity\Term;
use Drupal\Tests\UnitTestCase;
use Drupal\user\Entity\Role;
use Drupal\user\RoleStorageInterface;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the TermOperations class.
 *
 * @coversDefaultClass \Drupal\index_now\TermOperations
 *
 * @group index_now
 */
class TermOperationsTest extends UnitTestCase {

  use ProphecyTrait;

  const CONFIG_NAME = 'index_now.settings';

  const CONFIG_EXCLUDE_NAME = 'exclude_vocabularies';

  const PERMISSION = 'access content';

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->configFactory = $this->prophesize(ConfigFactoryInterface::class);
    $this->entityTypeManager = $this->prophesize(EntityTypeManagerInterface::class);
    $this->indexNow = $this->prophesize(IndexNowInterface::class);

    $this->roleStorage = $this->prophesize(RoleStorageInterface::class);
    $this->entityTypeManager
      ->getStorage('user_role')
      ->willReturn($this->roleStorage->reveal());

    $this->TermOperations = new TermOperations(
      $this->configFactory->reveal(),
      $this->entityTypeManager->reveal(),
      $this->indexNow->reveal()
    );
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsUnpublished(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(FALSE);

    $this->roleStorage->load(Argument::any())
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->TermOperations->isIndexable($term->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testUserCantAccessContent(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(FALSE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->TermOperations->isIndexable($term->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testVocabularyIsExcluded(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $term->bundle()
      ->ShouldBeCalled()
      ->willReturn('foo');

    $this->assertTrue(!$this->TermOperations->isIndexable($term->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testTermIsIndexable(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $term->bundle()
      ->ShouldBeCalled()
      ->willReturn('bar');

    $this->assertTrue($this->TermOperations->isIndexable($term->reveal()));
  }

}

==> index_now-3.1.1.tar.gz: index_now/tests/src/Unit/TermOperationsTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\index_now\TermOperations;
use Drupal\taxonomy\Entity\Term;
use Drupal\Tests\UnitTestCase;
use Drupal\user\Entity\Role;
use Drupal\user\RoleStorageInterface;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the TermOperations class.
 *
 * @coversDefaultClass \Drupal\index_now\TermOperations
 *
 * @group index_now
 */
class TermOperationsTest extends UnitTestCase {

  use ProphecyTrait;

  const CONFIG_NAME = 'index_now.settings';

  const CONFIG_EXCLUDE_NAME = 'exclude_vocabularies';

  const CONFIG_EXCLUDE_EVENTS_NAME = 'exclude_taxonomy_events';

  const PERMISSION = 'access content';

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The Index Now service.
   *
   * @var \Drupal\index_now\Service\IndexNowInterface
   */
  protected $indexNow;

  /**
   * The role storage.
   *
   * @var \Drupal\user\RoleStorageInterface
   */
  protected $roleStorage;

  /**
   * The Index Now term operations.
   *
   * @var \Drupal\index_now\TermOperations
   */
  protected $termOperations;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->configFactory = $this->prophesize(ConfigFactoryInterface::class);
    $this->entityTypeManager = $this->prophesize(EntityTypeManagerInterface::class);
    $this->indexNow = $this->prophesize(IndexNowInterface::class);

    $this->roleStorage = $this->prophesize(RoleStorageInterface::class);
    $this->entityTypeManager
      ->getStorage('user_role')
      ->willReturn($this->roleStorage->reveal());

    $this->termOperations = new TermOperations(
      $this->configFactory->reveal(),
      $this->entityTypeManager->reveal(),
      $this->indexNow->reveal()
    );
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsUnpublished(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(FALSE);

    $this->roleStorage->load(Argument::any())
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->termOperations->isIndexable($term->reveal(), 'foo'));
  }

  /**
   * @covers ::isIndexable
   */
  public function testUserCantAccessContent(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(FALSE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->termOperations->isIndexable($term->reveal(), 'foo'));
  }

  /**
   * @covers ::isIndexable
   */
  public function testEventIsExcluded(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $config = $this->prophesize(Config::class);
    $config
      ->get(self::CONFIG_EXCLUDE_EVENTS_NAME)
      ->ShouldBeCalled()
      ->willReturn([
        'foo' => 'foo',
        'bar' => 0,
      ]);
    $config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->ShouldNotBeCalled();

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($config->reveal());

    $this->assertTrue(!$this->termOperations->isIndexable($term->reveal(), 'foo'));
  }

  /**
   * @covers ::isIndexable
   */
  public function testVocabularyIsExcluded(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $config = $this->prophesize(Config::class);
    $config
      ->get(self::CONFIG_EXCLUDE_EVENTS_NAME)
      ->ShouldBeCalled()
      ->willReturn([
        'foo' => 0,
        'bar' => 0,
      ]);
    $config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->ShouldBeCalled()
      ->willReturn(['foobar']);

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($config->reveal());

    $term->bundle()
      ->ShouldBeCalled()
      ->willReturn('foobar');

    $this->assertTrue(!$this->termOperations->isIndexable($term->reveal(), 'foo'));
  }

  /**
   * @covers ::isIndexable
   */
  public function testTermIsIndexable(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $config = $this->prophesize(Config::class);
    $config
      ->get(self::CONFIG_EXCLUDE_EVENTS_NAME)
      ->ShouldBeCalled()
      ->willReturn([
        'foo' => 0,
        'bar' => 0,
      ]);
    $config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->ShouldBeCalled()
      ->willReturn(['barfoo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($config->reveal());

    $term->bundle()
      ->ShouldBeCalled()
      ->willReturn('foobar');

    $this->assertTrue($this->termOperations->isIndexable($term->reveal(), 'foo'));
  }

}
